@@ -97,6 +97,8 @@ class SimpleAPI(object):
             self._ = CharVariable()
         variables = [attr for attr in dir(self) if hasattr(self.__getattribute__(attr), 'simple_api_variable')]
         keys = []
+        if self.post:
+            self.get.update(self.post)
         for key, val in self.get.iteritems():
             if key in variables:
                 key_obj = self.__getattribute__(key)
